@@ -1,7 +1,5 @@
 package PPIx::EditorTools;
 
-# ABSTRACT: Utility methods and base class for manipulating Perl via PPI
-
 use 5.008;
 use strict;
 use warnings;
@@ -14,10 +12,14 @@ use Class::XSAccessor 1.02 constructor => 'new', accessors => {
 use PPI 1.203;
 use PPIx::EditorTools::ReturnObject;
 
-our $VERSION = '0.14';
+our $VERSION = '0.16';
 
 =pod
 
+=head1 NAME
+
+PPIx::EditorTools - Utility methods and base class for manipulating Perl via PPI
+
 =head1 SYNOPSIS
 
     See PPIx::EditorTools::*
@@ -348,6 +350,26 @@ __END__
 
 =pod
 
+=head1 AUTHORS
+
+Gabor Szabo E<lt>gabor@szabgab.comE<gt>
+
+=head2 CONTRIBUTORS
+
+ADAMK
+
+AZAWAWI
+
+BOWTIE
+
+buff3r
+
+MGRIMES
+
+PATRICKAS
+
+SMUELLER
+
 =head1 SEE ALSO
 
 C<PPIx::EditorTools::*>, L<Padre>, L<App::EditorTools>, L<Padre>, and L<PPI>.
